@@ -69,6 +69,7 @@ bool ts_guc_enable_foreign_key_propagation = true;
 TSDLLEXPORT bool ts_guc_enable_cagg_watermark_constify = true;
 TSDLLEXPORT int ts_guc_cagg_max_individual_materializations = 10;
 bool ts_guc_enable_osm_reads = true;
+TSDLLEXPORT bool ts_guc_enable_compressed_direct_batch_delete = true;
 TSDLLEXPORT bool ts_guc_enable_dml_decompression = true;
 TSDLLEXPORT bool ts_guc_enable_dml_decompression_tuple_filtering = true;
 TSDLLEXPORT int ts_guc_max_tuples_decompressed_per_dml = 100000;
@@ -87,6 +88,7 @@ static char *ts_guc_default_orderby_fn = NULL;
 TSDLLEXPORT bool ts_guc_enable_job_execution_logging = false;
 bool ts_guc_enable_tss_callbacks = true;
 TSDLLEXPORT bool ts_guc_enable_delete_after_compression = false;
+TSDLLEXPORT bool ts_guc_enable_merge_on_cagg_refresh = false;
 
 /* default value of ts_guc_max_open_chunks_per_insert and ts_guc_max_cached_chunks_per_hypertable
  * will be set as their respective boot-value when the GUC mechanism starts up */
@@ -112,16 +114,18 @@ char *ts_current_timestamp_mock = NULL;
 int ts_guc_debug_toast_tuple_target = 128;
 
 #ifdef TS_DEBUG
-static const struct config_enum_entry require_vector_qual_options[] = {
-	{ "allow", RVQ_Allow, false },
-	{ "forbid", RVQ_Forbid, false },
-	{ "only", RVQ_Only, false },
-	{ NULL, 0, false }
-};
+static const struct config_enum_entry debug_require_options[] = { { "allow", DRO_Allow, false },
+																  { "forbid", DRO_Forbid, false },
+																  { "require", DRO_Require, false },
+																  { NULL, 0, false } };
+
+DebugRequireOption ts_guc_debug_require_vector_qual = DRO_Allow;
+
+DebugRequireOption ts_guc_debug_require_vector_agg = DRO_Allow;
 #endif
 
-DebugRequireVectorQual ts_guc_debug_require_vector_qual = RVQ_Allow;
 bool ts_guc_debug_compression_path_info = false;
+bool ts_guc_enable_rowlevel_compression_locking = false;
 
 static bool ts_guc_enable_hypertable_create = true;
 static bool ts_guc_enable_hypertable_compression = true;
@@ -254,7 +258,7 @@ static bool
 check_segmentby_func(char **newval, void **extra, GucSource source)
 {
 	/* if the extension doesn't exist you can't check for the function, have to take it on faith */
-	if (ts_extension_is_loaded())
+	if (ts_extension_is_loaded_and_not_upgrading())
 	{
 		Oid segment_func_oid = get_segmentby_func(*newval);
 
@@ -296,7 +300,7 @@ static bool
 check_orderby_func(char **newval, void **extra, GucSource source)
 {
 	/* if the extension doesn't exist you can't check for the function, have to take it on faith */
-	if (ts_extension_is_loaded())
+	if (ts_extension_is_loaded_and_not_upgrading())
 	{
 		Oid func_oid = get_orderby_func(*newval);
 
@@ -463,6 +467,17 @@ _guc_init(void)
 							 NULL,
 							 NULL);
 
+	DefineCustomBoolVariable(MAKE_EXTOPTION("enable_compressed_direct_batch_delete"),
+							 "Enable direct deletion of compressed batches",
+							 "Enable direct batch deletion in compressed chunks",
+							 &ts_guc_enable_compressed_direct_batch_delete,
+							 true,
+							 PGC_USERSET,
+							 0,
+							 NULL,
+							 NULL,
+							 NULL);
+
 	DefineCustomIntVariable(MAKE_EXTOPTION("max_tuples_decompressed_per_dml_transaction"),
 							"The max number of tuples that can be decompressed during an "
 							"INSERT, UPDATE, or DELETE.",
@@ -559,6 +574,17 @@ _guc_init(void)
 							 NULL,
 							 NULL);
 
+	DefineCustomBoolVariable(MAKE_EXTOPTION("enable_merge_on_cagg_refresh"),
+							 "Enable MERGE statement on cagg refresh",
+							 "Enable MERGE statement on cagg refresh",
+							 &ts_guc_enable_merge_on_cagg_refresh,
+							 false,
+							 PGC_USERSET,
+							 0,
+							 NULL,
+							 NULL,
+							 NULL);
+
 	/*
 	 * Define the limit on number of invalidation-based refreshes we allow per
 	 * refresh call. If this limit is exceeded, fall back to a single refresh that
@@ -807,6 +833,17 @@ _guc_init(void)
 							 /* assign_hook= */ NULL,
 							 /* show_hook= */ NULL);
 
+	DefineCustomBoolVariable(/* name= */ MAKE_EXTOPTION("enable_rowlevel_compression_locking"),
+							 /* short_desc= */ "Use rowlevel locking during compression",
+							 /* long_desc= */ "Use only if you know what you are doing",
+							 /* valueAddr= */ &ts_guc_enable_rowlevel_compression_locking,
+							 /* bootValue= */ false,
+							 /* context= */ PGC_USERSET,
+							 /* flags= */ 0,
+							 /* check_hook= */ NULL,
+							 /* assign_hook= */ NULL,
+							 /* show_hook= */ NULL);
+
 #ifdef USE_TELEMETRY
 	DefineCustomStringVariable(/* name= */ "timescaledb_telemetry.cloud",
 							   /* short_desc= */ "cloud provider",
@@ -856,6 +893,19 @@ _guc_init(void)
 							/* assign_hook= */ NULL,
 							/* show_hook= */ NULL);
 
+	DefineCustomEnumVariable(/* name= */ MAKE_EXTOPTION("debug_require_vector_agg"),
+							 /* short_desc= */
+							 "ensure that vectorized aggregation is used or not",
+							 /* long_desc= */ "this is for debugging purposes",
+							 /* valueAddr= */ (int *) &ts_guc_debug_require_vector_agg,
+							 /* bootValue= */ DRO_Allow,
+							 /* options = */ debug_require_options,
+							 /* context= */ PGC_USERSET,
+							 /* flags= */ 0,
+							 /* check_hook= */ NULL,
+							 /* assign_hook= */ NULL,
+							 /* show_hook= */ NULL);
+
 	DefineCustomEnumVariable(/* name= */ MAKE_EXTOPTION("debug_require_vector_qual"),
 							 /* short_desc= */
 							 "ensure that non-vectorized or vectorized filters are used in "
@@ -866,8 +916,8 @@ _guc_init(void)
 							 "and "
 							 "using the test templates is a pain",
 							 /* valueAddr= */ (int *) &ts_guc_debug_require_vector_qual,
-							 /* bootValue= */ RVQ_Allow,
-							 /* options = */ require_vector_qual_options,
+							 /* bootValue= */ DRO_Allow,
+							 /* options = */ debug_require_options,
 							 /* context= */ PGC_USERSET,
 							 /* flags= */ 0,
 							 /* check_hook= */ NULL,
