@@ -31,6 +31,7 @@ extern TSDLLEXPORT bool ts_guc_enable_cagg_watermark_constify;
 extern bool ts_guc_enable_osm_reads;
 extern TSDLLEXPORT bool ts_guc_enable_dml_decompression;
 extern TSDLLEXPORT bool ts_guc_enable_dml_decompression_tuple_filtering;
+extern TSDLLEXPORT bool ts_guc_enable_compressed_direct_batch_delete;
 extern TSDLLEXPORT int ts_guc_max_tuples_decompressed_per_dml;
 extern TSDLLEXPORT bool ts_guc_enable_transparent_decompression;
 extern TSDLLEXPORT bool ts_guc_enable_compression_wal_markers;
@@ -44,6 +45,7 @@ extern int ts_guc_max_cached_chunks_per_hypertable;
 extern TSDLLEXPORT bool ts_guc_enable_job_execution_logging;
 extern bool ts_guc_enable_tss_callbacks;
 extern TSDLLEXPORT bool ts_guc_enable_delete_after_compression;
+extern TSDLLEXPORT bool ts_guc_enable_merge_on_cagg_refresh;
 
 #ifdef USE_TELEMETRY
 typedef enum TelemetryLevel
@@ -75,16 +77,22 @@ extern char *ts_current_timestamp_mock;
 
 extern TSDLLEXPORT int ts_guc_debug_toast_tuple_target;
 
-typedef enum DebugRequireVectorQual
+#ifdef TS_DEBUG
+typedef enum DebugRequireOption
 {
-	RVQ_Allow = 0,
-	RVQ_Forbid,
-	RVQ_Only
-} DebugRequireVectorQual;
+	DRO_Allow = 0,
+	DRO_Forbid,
+	DRO_Require
+} DebugRequireOption;
 
-extern TSDLLEXPORT DebugRequireVectorQual ts_guc_debug_require_vector_qual;
+extern TSDLLEXPORT DebugRequireOption ts_guc_debug_require_vector_qual;
+
+extern TSDLLEXPORT DebugRequireOption ts_guc_debug_require_vector_agg;
+
+#endif
 
 extern TSDLLEXPORT bool ts_guc_debug_compression_path_info;
+extern TSDLLEXPORT bool ts_guc_enable_rowlevel_compression_locking;
 
 extern TSDLLEXPORT bool ts_guc_debug_require_batch_sorted_merge;
 
