@@ -380,7 +380,7 @@ ts_hypertable_relid_to_id(Oid relid)
 {
 	Cache *hcache;
 	Hypertable *ht = ts_hypertable_cache_get_cache_and_entry(relid, CACHE_FLAG_MISSING_OK, &hcache);
-	int result = (ht == NULL) ? -1 : ht->fd.id;
+	int result = ht ? ht->fd.id : INVALID_HYPERTABLE_ID;
 
 	ts_cache_release(hcache);
 	return result;
@@ -1287,7 +1287,7 @@ hypertable_validate_constraints(Oid relid)
 
 		if (form->contype == CONSTRAINT_FOREIGN)
 		{
-			if (ts_hypertable_relid_to_id(form->confrelid) != -1)
+			if (ts_hypertable_relid_to_id(form->confrelid) != INVALID_HYPERTABLE_ID)
 				ereport(ERROR,
 						(errcode(ERRCODE_FEATURE_NOT_SUPPORTED),
 						 errmsg("hypertables cannot be used as foreign key references of "
@@ -1319,7 +1319,11 @@ hypertable_validate_constraints(Oid relid)
 	{
 		Form_pg_constraint form = (Form_pg_constraint) GETSTRUCT(tuple);
 
-		if (form->contype == CONSTRAINT_FOREIGN)
+		/*
+		 * Hypertable <-> hypertable foreign keys are not supported.
+		 */
+		if (form->contype == CONSTRAINT_FOREIGN &&
+			ts_hypertable_relid_to_id(form->conrelid) != INVALID_HYPERTABLE_ID)
 			ereport(ERROR,
 					(errcode(ERRCODE_INVALID_TABLE_DEFINITION),
 					 errmsg("cannot have FOREIGN KEY constraints to hypertable \"%s\"",
@@ -2000,6 +2004,9 @@ ts_hypertable_create_from_info(Oid table_relid, int32 hypertable_id, uint32 flag
 		ts_tablespace_attach_internal(&tspc_name, table_relid, false);
 	}
 
+	if ((flags & HYPERTABLE_CREATE_DISABLE_DEFAULT_INDEXES) == 0)
+		ts_indexing_create_default_indexes(ht);
+
 	/*
 	 * Migrate data from the main table to chunks
 	 *
@@ -2019,9 +2026,6 @@ ts_hypertable_create_from_info(Oid table_relid, int32 hypertable_id, uint32 flag
 
 	insert_blocker_trigger_add(table_relid);
 
-	if ((flags & HYPERTABLE_CREATE_DISABLE_DEFAULT_INDEXES) == 0)
-		ts_indexing_create_default_indexes(ht);
-
 	ts_cache_release(hcache);
 
 	return true;
